@@ -115,10 +115,6 @@ def dt_challenges_evaluator_(args: List[str] = None, token: str = None):
 Usage:
 
 """
-    # args = sys.argv[1:]
-    # if args and args[0].startswith("dt-"):
-    #     elogger.debug("removing first arg from %s" % args)
-    #     args = args[1:]
     prog = "dt-challenges-evaluator"
     parser = argparse.ArgumentParser(prog=prog, usage=usage)
     parser.add_argument("--version", action="store_true", default=False)
@@ -133,6 +129,9 @@ Usage:
     parser.add_argument("--machine-id", default=None, help="Machine name")
     parser.add_argument("--name", default=None, help="Evaluator name")
     parser.add_argument("--impersonate", default=None)
+    DEFAULT_TMPDIR = "/tmp/duckietown/DT18/evaluator/executions"
+
+    parser.add_argument("--tmpdir", default=DEFAULT_TMPDIR)
     parser.add_argument("--submission", default=None, help="evaluate this particular submission")
     parser.add_argument(
         "--reset", dest="reset", action="store_true", default=False, help="Reset submission",
@@ -159,8 +158,7 @@ Usage:
         msg = "Could not find docker-compose. Please install it."
         msg += "\n\nSee: https://docs.docker.com/compose/install/#install-compose"
         raise InvalidEnvironment(msg)
-
-    tmpdir = "/tmp/duckietown/DT18/evaluator/executions"
+    tmpdir = parsed.tmpdir
 
     try:
         more_features = yaml.load(parsed.features, Loader=yaml.SafeLoader)
